@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: glib
-version: 0.12.0
-id: glib-0.12.0-58f533cd92d47371ecb1bc085e466fee
+version: 0.12.3.1
+id: glib-0.12.3.1-802d98cfe9a88c3ac80f8e30d4b86d4a
 
 license: LGPL-2.1
 copyright: (c) 2001-2010 The Gtk2Hs Team
-maintainer: gtk2hs-users@sourceforge.net
+maintainer: gtk2hs-users@lists.sourceforge.net
 stability: stable
-homepage: http://www.haskell.org/gtk2hs/
+homepage: http://projects.haskell.org/gtk2hs/
 package-url:
+synopsis: Binding to the GLIB library for Gtk2Hs.
 description: The GNU Library is a collection of C data structures and utility
              function for dealing with Unicode. This package only binds as
              much functionality as required to support the packages that
@@ -22,25 +23,26 @@ exposed-modules: System.Glib System.Glib.GError
                  System.Glib.MainLoop System.Glib.GDateTime System.Glib.GObject
                  System.Glib.Utils System.Glib.StoreValue System.Glib.FFI
                  System.Glib.Flags System.Glib.UTFString System.Glib.Types
-                 System.Glib.GList System.Glib.GType System.Glib.GTypeConstants
-                 System.Glib.GValue System.Glib.GValueTypes System.Glib.GParameter
+                 System.Glib.GList System.Glib.GString System.Glib.GType
+                 System.Glib.GTypeConstants System.Glib.GValue
+                 System.Glib.GValueTypes System.Glib.GParameter
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/glib-0.12.0
-library-dirs: /usr/local/lib/ghc/glib-0.12.0 /usr/local/lib
-hs-libraries: HSglib-0.12.0
-extra-libraries: gobject-2.0 gthread-2.0 glib-2.0 intl iconv
+trusted: False
+import-dirs: /usr/local/lib/ghc/glib-0.12.3.1
+library-dirs: /usr/local/lib/ghc/glib-0.12.3.1 /usr/local/lib
+hs-libraries: HSglib-0.12.3.1
+extra-libraries: gobject-2.0 glib-2.0 intl iconv
 extra-ghci-libraries:
 include-dirs: /usr/local/include/glib-2.0
-              /usr/local/lib/glib-2.0/include
+              /usr/local/lib/glib-2.0/include /usr/local/include
 includes:
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
-         haskell98-1.1.0.1-3ce559675b118e85a39def472ca9857c
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
 hugs-options:
 cc-options:
-ld-options: -pthread
+ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-glib-0.12.0/html/glib.haddock
-haddock-html: /usr/local/share/doc/hs-glib-0.12.0/html
+haddock-interfaces: /usr/local/share/doc/hs-glib-0.12.3.1/html/glib.haddock
+haddock-html: /usr/local/share/doc/hs-glib-0.12.3.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
